==> editics-1.0.1.tar.gz: editics/modules/cri_php_word/src/convertor/Soffice.php <==
<?php
namespace Drupal\cri_php_word\convertor;

use Symfony\Component\Process\Exception\ProcessFailedException;
use Symfony\Component\Process\Process;

class Soffice extends Convertor
{
  /**
   * @param $destination
   * @param null $format
   * @return mixed|void
   */
  public function convert($destination, $format = NULL): array
  {
    if (empty($this->files)) {
      return ['errorCode' => 1, 'message' => 'Aucun fichier à convertir.'];
    }
    $PID = uniqid();
    $port = rand(10000, 20000);
    $outdir = dirname($this->files[0]);

    // Commande avec multiprocess
    /*
    $cmd = 'export HOME=/tmp && soffice ' .
      '--headless ' .
      '--nologo ' . 
      '"-env:UserInstallation=file:///tmp/lib0_Conversion__' . $PID . '" ' .
      '--accept="socket,port=' . $port. ';urp" ' .
      '--convert-to pdf:writer_pdf_Export --outdir ' . $outdir . ' ' . implode(' ', $this->files);
*/
    // Commande sans multiprocess

    $cmd = 'export HOME=/tmp && soffice ' .
      '--convert-to pdf:writer_pdf_Export ' .
      '--headless ' .
      '--nologo ' .
      '"-env:UserInstallation=file:///tmp/lib0_Conversion__' . $PID . '" ' .
      '--accept="socket,port=' . $port. ';urp" ' .
      '--outdir ' . $outdir . ' ' . implode(' ', $this->files);
    $process = new Process($cmd);
    try {
      $process->mustRun();
      return ['errorCode' => 0, 'files' => $this->destinations];
    } catch (ProcessFailedException $ex) {
      return ['errorCode' => 1, 'message' => $ex->getMessage()];
    }
  }
}

==> editics-1.0.6.tar.gz: editics/modules/cri_php_word/src/convertor/Soffice.php <==
<?php
namespace Drupal\cri_php_word\convertor;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\Process\Exception\ProcessFailedException;
use Symfony\Component\Process\Process;

class Soffice extends Convertor
{
  use StringTranslationTrait;

  /**
   * @param $destination
   * @param null $format
   * @return mixed|void
   */
  public function convert($destination, $format = NULL): array
  {
    if (empty($this->files)) {
      return ['errorCode' => 1, 'message' => $this->t('No file to convert.')];
    }
    $PID = uniqid();
    $port = rand(10000, 20000);
    $outdir = dirname($this->files[0]);

    // Commande avec multiprocess
    /*
    $cmd = 'export HOME=/tmp && soffice ' .
      '--headless ' .
      '--nologo ' . 
      '"-env:UserInstallation=file:///tmp/lib0_Conversion__' . $PID . '" ' .
      '--accept="socket,port=' . $port. ';urp" ' .
      '--convert-to pdf:writer_pdf_Export --outdir ' . $outdir . ' ' . implode(' ', $this->files);
*/
    // Commande sans multiprocess

    $cmd = 'export HOME=/tmp && soffice ' .
      '--convert-to pdf:writer_pdf_Export ' .
      '--headless ' .
      '--nologo ' .
      '"-env:UserInstallation=file:///tmp/lib0_Conversion__' . $PID . '" ' .
      '--accept="socket,port=' . $port. ';urp" ' .
      '--outdir ' . $outdir . ' ' . implode(' ', $this->files);
    $process = new Process($cmd);
    try {
      $process->mustRun();
      return ['errorCode' => 0, 'files' => $this->destinations];
    } catch (ProcessFailedException $ex) {
      return ['errorCode' => 1, 'message' => $ex->getMessage()];
    }
  }
}
